@@ -15,17 +15,32 @@
 
 # pylint: disable=g-multiple-import
 from xarray_beam._src.core import (
-    ChunkKey,
+    Key,
     DatasetToChunks,
+    ValidateEachChunk,
+    offsets_to_slices,
+    validate_chunk
+)
+from xarray_beam._src.combiners import (
+    MeanCombineFn,
 )
 from xarray_beam._src.rechunk import (
     ConsolidateChunks,
+    ConsolidateVariables,
     SplitChunks,
+    SplitVariables,
     Rechunk,
+    consolidate_chunks,
+    consolidate_variables,
+    consolidate_fully,
+    split_chunks,
+    split_variables,
+    in_memory_rechunk,
 )
 from xarray_beam._src.zarr import (
     ChunksToZarr,
     DatasetToZarr,
 )
+from xarray_beam import Mean
 
-__version__ = '0.0.1'
+__version__ = '0.3.0'
